@@ -3,11 +3,13 @@ from __future__ import annotations
 import contextlib
 import os
 import sys
+from pathlib import Path
 from stat import S_IWGRP, S_IWOTH, S_IWUSR
 from subprocess import Popen, check_call
 from threading import Thread
 
 import pytest
+from pytest_mock import MockerFixture
 
 from virtualenv.discovery import cached_py_info
 from virtualenv.discovery.py_info import PythonInfo
@@ -202,7 +204,7 @@ def test_populated_read_only_cache_and_copied_app_data(tmp_path, current_fastest
 @pytest.mark.parametrize("pkg", ["pip", "setuptools", "wheel"])
 @pytest.mark.usefixtures("session_app_data", "current_fastest", "coverage_env")
 def test_base_bootstrap_link_via_app_data_no(tmp_path, pkg):
-    create_cmd = [str(tmp_path), "--seeder", "app-data", f"--no-{pkg}"]
+    create_cmd = [str(tmp_path), "--seeder", "app-data", f"--no-{pkg}", "--wheel", "bundle", "--setuptools", "bundle"]
     result = cli_run(create_cmd)
     assert not (result.creator.purelib / pkg).exists()
     for key in {"pip", "setuptools", "wheel"} - {pkg}:
@@ -216,7 +218,7 @@ def test_app_data_parallel_ok(tmp_path):
 
 
 @pytest.mark.usefixtures("temp_app_data")
-def test_app_data_parallel_fail(tmp_path, mocker):
+def test_app_data_parallel_fail(tmp_path: Path, mocker: MockerFixture) -> None:
     mocker.patch("virtualenv.seed.embed.via_app_data.pip_install.base.PipInstall.build_image", side_effect=RuntimeError)
     exceptions = _run_parallel_threads(tmp_path)
     assert len(exceptions) == 2
@@ -230,7 +232,7 @@ def _run_parallel_threads(tmp_path):
 
     def _run(name):
         try:
-            cli_run(["--seeder", "app-data", str(tmp_path / name), "--no-pip", "--no-setuptools"])
+            cli_run(["--seeder", "app-data", str(tmp_path / name), "--no-pip", "--no-setuptools", "--wheel", "bundle"])
         except Exception as exception:
             as_str = str(exception)
             exceptions.append(as_str)
